@@ -8,10 +8,10 @@ use parent 'Class::Accessor';
 
 use DateTime::Format::Duration;
 
-our $VERSION = '1.01';
+our $VERSION = '1.02';
 
 Travel::Status::DE::URA::Result->mk_ro_accessors(
-	qw(datetime destination line line_id stop stop_id));
+	qw(datetime destination line line_id stop stop_id stop_indicator));
 
 sub new {
 	my ( $obj, %conf ) = @_;
@@ -144,7 +144,7 @@ departure received by Travel::Status::DE::URA
 
 =head1 VERSION
 
-version 1.01
+version 1.02
 
 =head1 DESCRIPTION
 
@@ -219,6 +219,12 @@ The stop (name, not object) belonging to this departure.
 
 The stop ID belonging to this departure.
 
+=item $departure->stop_indicator
+
+The indicator for this departure at the corresponding stop, usually
+describes a platform or sub-stop number.  undef if the stop does not
+have such a distinction.
+
 =item $departure->time
 
 Departure time (HH:MM:SS).
